@@ -1,7 +1,7 @@
 package IPC::System::Options;
 
-our $DATE = '2015-04-21'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2015-05-15'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -38,6 +38,8 @@ sub _system_or_backtick {
     my $opts = ref($_[0]) eq 'HASH' ? shift : {};
     $opts->{$_} //= $Global_Opts{$_} for keys %Global_Opts;
 
+    my $opt_die = $opts->{die} || $opts->{dies};
+
     # set ENV
     my %save_env;
     my %set_env;
@@ -132,7 +134,7 @@ sub _system_or_backtick {
                      $which, \@_, $?, explain_child_error())
             if $opts->{log};
         croak "$which(".join(" ", @_).") failed: " . explain_child_error()
-            if $opts->{die};
+            if $opt_die;
     }
 
     return $wa ? @$res : $res;
@@ -161,7 +163,7 @@ IPC::System::Options - Perl's system() and backtick/qx replacement/wrapper, with
 
 =head1 VERSION
 
-This document describes version 0.09 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-04-21.
+This document describes version 0.10 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-05-15.
 
 =head1 SYNOPSIS
 
